location_max_web

The web implementation of location_max.

技术支持邮箱(1539841933@qq.com)。

Usage

Import the package

This package is the endorsed implementation of location_max for the web platform since version 3.0.0, so it gets automatically added to your dependencies by depending on location_max: ^7.0.0.

No modifications to your pubspec.yaml should be required in a recent enough version of Flutter (>=1.12.13+hotfix.4):

...
dependencies:
  ...
  location_max: ^7.0.0
  ...

Once you have location_max in pubspec.yaml you should be able to use package:location_max as normal.

Libraries

location_max_web